Demo for MAXREFDES99

Dependencies:   MAX7219 mbed

Revision:
6:00aabe967e51
Parent:
3:41bdbc9b3cec
Child:
8:a6a0c9e280ae
--- a/maxrefdes99.h	Mon Apr 11 16:19:13 2016 +0000
+++ b/maxrefdes99.h	Wed Apr 27 10:27:34 2016 +0000
@@ -3,13 +3,14 @@
 *
 * @author Justin Jordan
 *
-* @version 0.1
+* @version 0.2
 *
 * Started: 08JAN16
 *
-* Updated: 11APR16,Pradip Vatharkar 
+* Updated: 26 APR16,Pradip Vatharkar 
 *
-* @brief Header file for maxrefdes99 demo with 5x7 & 16x16 fonts  
+* @brief Source file for maxrefdes99 demo with 5x7, 16x16 aerial bold 
+* and 16x16 manual fonts   
 ***********************************************************************
 * Copyright (C) 2016 Maxim Integrated Products, Inc., All Rights Reserved.
 *
@@ -236,11 +237,11 @@
 *     @param[in] c - character to get bitmap for
 *     @param[in] char_buff - pointer to buffer to store bitmap 
 *                            Buffer should be 32 bytes
-*
+*     @param[in] font_type - 16x16 font type used for display 
 * On Exit:
 *    @return none
 **************************************************************/
-void get_16x16_character(char c, uint8_t *char_buff);
+void get_16x16_character(char c, uint8_t *char_buff,uint8_t font_type);
 
 
 /**********************************************************//**
@@ -253,11 +254,12 @@
       @param[in] position -  for single char print this value is zero,
                  for string case it is multiple of 32 bytes as each char data is 32 bytes, 
 *     @param[in] c - char to print
+*     @param[in] font_type - 16x16 font type used for display 
 *
 * On Exit:
 *    @return none
 **************************************************************/
-void print_char_16x16(Max7219 *p_display, uint16_t position, char c);
+void print_char_16x16(Max7219 *p_display, uint16_t position, char c,uint8_t font_type);
 
 
 /**********************************************************//**
@@ -268,15 +270,16 @@
 * On Entry:
 *     @param[in] p_display - pointer to Max7219 object
 *     @param[in] s - pointer to string to print
+*     @param[in] font_type - 16x16 font type used for display 
 *
 * On Exit:
 *    @return none
 **************************************************************/
-void print_string_16x16(Max7219 *p_display, char *s);
+void print_string_16x16(Max7219 *p_display, char *s, uint8_t font_type);
 
 
 /**********************************************************//**
 * @brief shifts display right 'count' positions with given
 *        delay between shifts 
 * 
 * @details 
@@ -293,7 +296,7 @@
 
 
 /**********************************************************//**
 * @brief shifts display left 'count' positions with given
 *        delay between shifts
 * 
 * @details 
@@ -316,16 +319,17 @@
 * On Entry:
 *     @param[in] p_display - pointer to Max7219 object
 *     @param[in] display_config - structure holding configuration data
+*     @param[in] font_type - 16x16 font type used for display 
 *     @param[in] endless_loop - if true run demo in endless loop
 *
 * On Exit:
 *    @return none
 **************************************************************/
-void demo_16x16(Max7219 *display, max7219_configuration_t display_config, bool endless_loop);
+void demo_16x16(Max7219 *display, max7219_configuration_t display_config,uint8_t font_type, bool endless_loop);
 
 
 /**********************************************************//**
 * @brief shift display in given direction forever
 * 
 * @details 
 *
@@ -268,15 +270,16 @@
 
 /**********************************************************//**
-* @brief shifts display right 'count' positions with given
+* @brief shifts 16x16 font display right 'count' positions with given
 *        delay between shifts 
 * 
@@ -293,7 +296,7 @@
 
 /**********************************************************//**
-* @brief shifts display left 'count' positions with given
+* @brief shifts 16x16 font display left 'count' positions with given
 *        delay between shifts
 * 
@@ -316,16 +319,17 @@
 
 /**********************************************************//**
-* @brief shift display in given direction forever
+* @brief shift 16x16 font display in given direction forever
 * 
 * @details 